setwd("/home/sesa/Scrivania/")
pdf("/home/sesa/Scrivania/output.pdf")
#Load Data
data<-read.table("stats.csv",sep=",",header=TRUE)

#id,author,bug,somiglianza,numfile

#id : commit ID
#author : commit's author
#bug : true if commit is a fix inducing changes
#somiglianza : commit similarity
#numfile : num of file touched by commit

#Subsets
data2 <- data[which(data["somiglianza"] != "NaN"),]

bug <- data2[which(data2["bug"] == "true"),]
no_bug <- data2[which(data2["bug"] == "false"),]

bug_Not1 <- bug[which(bug["numfile"] > 1),]
no_bug_Not1 <- no_bug[which(no_bug["numfile"] > 1),]

#Summary info
print("----------- Summary Info -----------")
print("Summary Somiglianza (BUG)")
summary(bug$somiglianza)
print("Summary Somiglianza (NO_BUG)")
summary(no_bug$somiglianza)
print("Summary Somiglianza [file > 1] (BUG)")
summary(bug_Not1$somiglianza)
print("Summary Somiglianza [file > 1] (NO_BUG)")
summary(no_bug_Not1$somiglianza)

print("Summary Touched File (BUG)")
summary(bug$numfile)
print("Summary Touched File (NO_BUG)")
summary(no_bug$numfile)
print("Summary Touched File [file > 1] (BUG)")
summary(bug_Not1$numfile)
print("Summary Touched File [file > 1] (NO_BUG)")
summary(no_bug_Not1$numfile)

#Boxplots
#Similarity
boxplot(no_bug$somiglianza, bug$somiglianza, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Somiglianza")
boxplot(no_bug_Not1$somiglianza, bug_Not1$somiglianza, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Somiglianza [file > 1]")

#NumFile
boxplot(no_bug$numfile, bug$numfile, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Num File Touched")
boxplot(no_bug_Not1$numfile, bug_Not1$numfile, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Num File Touched  [file > 1]")


#Statistical test
print("----------- Statistical Test - WilcoxTest -----------")
wilcox.test(bug$somiglianza, no_bug$somiglianza,alternative="less",paired=FALSE)
wilcox.test(bug_Not1$somiglianza, no_bug_Not1$somiglianza,alternative="less",paired=FALSE)
wilcox.test(no_bug$numfile, bug$numfile,alternative="less",paired=FALSE)
wilcox.test(no_bug_Not1$numfile, bug_Not1$numfile,alternative="less",paired=FALSE)

library(orddom)

#small for d < 0.33 (positive as well as negative values), 
#medium for 0.33 ≤ d < 0.474 and large for d ≥ 0.474.
#Summary info
print("----------- Cliff's Delta -----------")
print("Somiglianza")
t1=as.matrix(no_bug$somiglianza)
colnames(t1)<-c("t1")
t2=as.matrix(bug$somiglianza)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Somiglianza [file > 1]")
t1=as.matrix(no_bug_Not1$somiglianza)
colnames(t1)<-c("t1")
t2=as.matrix(bug_Not1$somiglianza)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Num File Touched")
t1=as.matrix(no_bug$numfile)
colnames(t1)<-c("t1")
t2=as.matrix(bug$numfile)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Num File Touched [file > 1]")
t1=as.matrix(no_bug_Not1$numfile)
colnames(t1)<-c("t1")
t2=as.matrix(bug_Not1$numfile)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta

dev.off()
