setwd("/home/sesa/Scrivania/")
pdf("/home/sesa/Scrivania/boxplots.pdf")
#Load Data
data<-read.table("stats.csv",sep=",",header=TRUE)


#id,bug,ccdb,ccdbm,ccdbmm,kdb,cct,cctm,cctmm,kt

#id : commit ID
#bug : true if commit is a fix inducing change
#ccdb : Conceptual Coupling Dynamic Background (text currentCommit - text background)
#ccdbm : Conceptual Coupling Dynamic Background (mean foreach file: text file - text background)
#ccdbmm : Conceptual Coupling Dynamic Background (median foreach file: text file - text background)
#kdb : Knowledge Dynamic Background
#cct : Conceptual Coupling Progressive Loss of Memory Time Treshold (text currentCommit - text background)
#cctm : Conceptual Coupling Progressive Loss of Memory Time Treshold (mean foreach file: text file - text background)
#cctmm : Conceptual Coupling Progressive Loss of Memory Time Treshold (median foreach file: text file - text background)
#kt : Knowledge Progressive Loss of Memory Time Treshold

#This is the mapping for the variables used in the paper:
#ExpLex -> CCDBM
#ExpRecLex -> CCTM
#ExpFreq -> KDB
#ExpRecFreq -> KT 


#Subsets
bug <- data[which(data["bug"] == "true"),]
no_bug <- data[which(data["bug"] == "false"),]

#Summary info
print("----------- Summary Info -----------")
print("Summary Conceptual Coupling Dynamic Background (BUG)")
summary(bug$ccdb)
print("Summary Conceptual Coupling Dynamic Background (NO_BUG)")
summary(no_bug$ccdb)
print("Summary Conceptual Coupling Dynamic Background - Mean (BUG)")
summary(bug$ccdbm)
print("Summary Conceptual Coupling Dynamic Background - Mean (no_BUG)")
summary(no_bug$ccdbm)
print("Summary Conceptual Coupling Dynamic Background - Median (BUG)")
summary(bug$ccdbmm)
print("Summary Conceptual Coupling Dynamic Background - Median (NO_BUG)")
summary(no_bug$ccdbmm)
print("Knowledge Dynamic Background (BUG)");
summary(bug$kdb)
print("Knowledge Dynamic Background (NO_BUG)");
summary(no_bug$kdb)
print("Conceptual Coupling Progressive Loss of Memory Time Treshold (BUG)")
summary(bug$cct)
print("Conceptual Coupling Progressive Loss of Memory Time Treshold (NO_BUG)")
summary(no_bug$cct)
print("Conceptual Coupling Progressive Loss of Memory Time Treshold - Mean (BUG)")
summary(bug$cctm)
print("Conceptual Coupling Progressive Loss of Memory Time Treshold - Mean (NO_BUG)")
summary(no_bug$cctm)
print("Conceptual Coupling Progressive Loss of Memory Time Treshold - Median (BUG)")
summary(bug$cctmm)
print("Conceptual Coupling Progressive Loss of Memory Time Treshold - Median (NO_BUG)")
summary(no_bug$cctmm)
print("Knowledge Progressive Loss of Memory Time Treshold (BUG)");
summary(bug$kt)
print("Knowledge Progressive Loss of Memory Time Treshold (NO_BUG)");
summary(no_bug$kt)


#Boxplots
#Dynamic Background
boxplot(no_bug$ccdb, bug$ccdb, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Conceptual Coupling Dynamic Background")
boxplot(no_bug$ccdbm, bug$ccdbm, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Conceptual Coupling Dynamic Background - Mean")
boxplot(no_bug$ccdbmm, bug$ccdbmm, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Conceptual Coupling Dynamic Background - Median")
boxplot(no_bug$kdb, bug$kdb, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Knowledge Dynamic Background")

#Time Treshold
boxplot(no_bug$cct, bug$cct, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Coupling Progressive Loss of Memory Time Treshold")
boxplot(no_bug$cctm, bug$cctm, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Coupling Progressive Loss of Memory Time Treshold - Mean")
boxplot(no_bug$cctmm, bug$cctmm, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Coupling Progressive Loss of Memory Time Treshold - Median")
boxplot(no_bug$kt, bug$kt, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Conceptual Coupling", main="Knowledge Progressive Loss of Memory Time Treshold")


#Statistical test
print("----------- Statistical Test - WilcoxTest -----------")
wilcox.test(no_bug$ccdb, bug$ccdb,alternative="less",paired=FALSE)
wilcox.test(no_bug$ccdbm, bug$ccdbm,alternative="less",paired=FALSE)
wilcox.test(no_bug$ccdbmm, bug$ccdbmm,alternative="less",paired=FALSE)
wilcox.test(no_bug$kdb, bug$kdb,alternative="less",paired=FALSE)
wilcox.test(no_bug$cct, bug$cct,alternative="less",paired=FALSE)
wilcox.test(no_bug$cctm, bug$cctm,alternative="less",paired=FALSE)
wilcox.test(no_bug$cctmm, bug$cctmm,alternative="less",paired=FALSE)
wilcox.test(no_bug$kt, bug$kt,alternative="less",paired=FALSE)

library(orddom)

#small for d < 0.33 (positive as well as negative values), 
#medium for 0.33 ≤ d < 0.474 and large for d ≥ 0.474.
#Summary info
print("----------- Cliff's Delta -----------")
print("Conceptual Coupling Dynamic Background")
t1=as.matrix(no_bug$ccdb)
colnames(t1)<-c("t1")
t2=as.matrix(bug$ccdb)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Conceptual Coupling Dynamic Background - Mean")
t1=as.matrix(no_bug$ccdbm)
colnames(t1)<-c("t1")
t2=as.matrix(bug$ccdbm)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Summary Conceptual Coupling Dynamic Background - Median")
t1=as.matrix(no_bug$ccdbmm)
colnames(t1)<-c("t1")
t2=as.matrix(bug$ccdbmm)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Knowledge Dynamic Background");
t1=as.matrix(no_bug$kdb)
colnames(t1)<-c("t1")
t2=as.matrix(bug$kdb)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Conceptual Coupling Progressive Loss of Memory Time Treshold")
t1=as.matrix(no_bug$cct)
colnames(t1)<-c("t1")
t2=as.matrix(bug$cct)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Conceptual Coupling Progressive Loss of Memory Time Treshold - Mean")
t1=as.matrix(no_bug$cctm)
colnames(t1)<-c("t1")
t2=as.matrix(bug$cctm)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Conceptual Coupling Progressive Loss of Memory Time Treshold - Median")
t1=as.matrix(no_bug$cctmm)
colnames(t1)<-c("t1")
t2=as.matrix(bug$cctmm)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Knowledge Progressive Loss of Memory Time Treshold");
t1=as.matrix(no_bug$kt)
colnames(t1)<-c("t1")
t2=as.matrix(bug$kt)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta

dev.off()
