setwd("/home/sesa/Scrivania/")
pdf("/home/sesa/Scrivania/boxplots.pdf")
#Load Data
data<-read.table("stats.csv",sep=",",header=TRUE)

#id,author,bug,interferences,lines,interferencesforbug,linesforbug
#id : commit ID
#author : commit's author
#bug : true if commit is fix inducing changes
#interferences : num interferences
#lines : num of lines of interferences
#interferencesforbug :  num interferences only on bug file
#linesforbug : num of lines of interferences only on bug file

#Subsets
bug <- data[which(data["bug"] == "true"),]
no_bug <- data[which(data["bug"] == "false"),]

#Summary info
print("----------- Summary Info -----------")
print("Summary Interferences (BUG)")
summary(bug$interferences)
print("Summary Interferences (NO_BUG)")
summary(no_bug$interferences)
print("Summary Size Interferences (BUG)")
summary(bug$lines)
print("Summary Size Interferences (NO_BUG)")
summary(no_bug$lines)

#Boxplots
boxplot(no_bug$interferences, bug$interferences, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Interferences", main="Number of Interferences")
boxplot(no_bug$lines, bug$lines, col="gray", boxwex = 0.25, at = 1:2 - 0.0, names = c("NO","YES"), xlab="Fix Inducing Changes", ylab="Lines of Interferences", main="Size Interferences")


#Statistical test
print("----------- Statistical Test - WilcoxTest -----------")
wilcox.test(no_bug$interferences, bug$interferences,alternative="less",paired=FALSE)
wilcox.test(no_bug$lines, bug$lines,alternative="less",paired=FALSE)

library(orddom)

#small for d < 0.33 (positive as well as negative values), 
#medium for 0.33 ≤ d < 0.474 and large for d ≥ 0.474.
#Summary info
print("----------- Cliff's Delta -----------")
print("Interferences")
t1=as.matrix(no_bug$interferences)
colnames(t1)<-c("t1")
t2=as.matrix(bug$interferences)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta
print("Size Interferences")
t1=as.matrix(no_bug$lines)
colnames(t1)<-c("t1")
t2=as.matrix(bug$lines)
colnames(t2)<-c("t2")
o<-orddom(t1,t2)
cliffdelta<-o[13,1]
cliffdelta


dev.off()
